@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 #----------------------------------------------------------------------------
 
@@ -1902,7 +1902,7 @@ sub _count_mailrc {
 
     my $fh  = IO::File->new($mailrc,'r')     or die "Cannot read file [$mailrc]: $!\n";
     while(<$fh>) {
-        last    if(/^alias\s*DBIML/);
+        next    unless(/^alias\s*\w/);
         $count++;
     }
     $fh->close;
